@@ -16,8 +16,8 @@
 **
 ** You should have received a copy of the GNU General Public License
 ** along with this program in a file called COPYING; if not, write to
-** the Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
-** MA 02111-1307, USA.
+** the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+** MA 02110-1301, USA.
 */
 
 /*
@@ -68,6 +68,7 @@ DEBAPT::DEBAPT():DEB()
   paramsInst.append(new param(i18n("No download"),FALSE,FALSE,"--no-download"));
   paramsInst.append(new param(i18n("Ignore missing"),FALSE,FALSE,"-m"));
   paramsInst.append(new param(i18n("Ignore hold"),FALSE,FALSE,"--ignore-hold"));
+  paramsInst.append(new param(i18n("Allow Unauthenticated"),FALSE,FALSE,"--allow-unauthenticated"));
   paramsInst.append(new param(i18n("Assume yes"),TRUE,FALSE,"--yes"));
   paramsInst.append(new param(i18n("Test (do not uninstall)"),FALSE,FALSE,"-s"));
 
@@ -79,6 +80,8 @@ DEBAPT::DEBAPT():DEB()
 
   noFetch = TRUE;
   hasSearchAll = TRUE;
+
+  hasProgram = ifExe("apt-get");
 }
 
 //////////////////////////////////////////////////////////////////////////////
@@ -124,30 +127,37 @@ void DEBAPT::setMenu(KActionCollection*, bool enable)
 
 void DEBAPT::updateS()
 {
- kprun->run("apt-get update", "APT update");
- if (kprun->exec())
-   kpackage->management->collectData(TRUE);
- }
+  if (kprun->run("apt-get update", "APT update")) {
+    if (kprun->exec())
+      kpackage->management->collectData(TRUE);
+  }
+}
 
 void DEBAPT::upgradeS()
 {
- kprun->run(env + "apt-get upgrade", "APT upgrade");
- if (kprun->exec())
-   kpackage->management->collectData(TRUE);
- }
+  if (kprun->run(env + "apt-get upgrade", "APT upgrade")) {
+    if (kprun->exec())
+      kpackage->management->collectData(TRUE);
+  }
+}
 
 void DEBAPT::fixupS()
 {
- kprun->run(env + "apt-get -f install", "APT fixup");
- if (kprun->exec())
-   kpackage->management->collectData(TRUE);
+  if (kprun->run(env + "apt-get -f install", "APT fixup")) {
+    if (kprun->exec())
+      kpackage->management->collectData(TRUE);
+  }
 }
 
 void DEBAPT::fileS()
 {
- kprun->run(env + "apt-file update", "APT file update");
- if (kprun->exec())
-   kpackage->management->collectData(TRUE);
+  if (ifExe("apt-file") || !hostName.isEmpty()) {
+    if (kprun->run(env + "apt-file update", "APT file update")) {
+      kprun->exec();
+   } 
+  } else {
+    KpMsg("Error",i18n("The %1 program needs to be installed").arg("apt-file"), TRUE);
+  }
 }
 
 void DEBAPT::listPackages(QPtrList<packageInfo> *pki)
@@ -278,7 +288,7 @@ void DEBAPT::listAvail(QPtrList<packageInfo> *pki)
   kpackage->setPercent(100);
 }
 
-QStringList  DEBAPT::listInstalls(QStringList packs, bool install)
+QStringList  DEBAPT::listInstalls(const QStringList &packs, bool install, bool &cancel)
 {
   bool extras=FALSE, found=FALSE;
 
@@ -292,16 +302,21 @@ QStringList  DEBAPT::listInstalls(QStringList packs, bool install)
     s += "remove ";
   }
 
-  for ( QStringList::Iterator it = packs.begin(); it != packs.end(); ++it ) {
+  for ( QStringList::ConstIterator it = packs.begin(); it != packs.end(); ++it ) {
     s +=  *it;
     s += " ";
   }
 
   QStringList list = kpty->run(s, TRUE, TRUE);
+  if (!kpty->inSession) {
+    cancel = TRUE; // Root login did not work
+  } else {
+    cancel = FALSE;
+  }
   //  kdDebug() << "LS=" << list.count()  << "\n";
 
   QString packAll;
-  for ( QStringList::Iterator it = list.begin(); it != list.end(); ++it ) {
+  for ( QStringList::ConstIterator it = list.begin(); it != list.end(); ++it ) {
     //        kdDebug() << "M=" << *it << "\n";
     if ((*it).find(match) >= 0 || extras) {
       if (extras) {
@@ -329,25 +344,31 @@ QStringList  DEBAPT::listInstalls(QStringList packs, bool install)
 QStringList DEBAPT::FindFile(const QString &name, bool searchAll)
 {
   if (searchAll) {
-    QString s = "apt-file search  ";
-    s += name;
+    if (ifExe("apt-file") || !hostName.isEmpty()) {
+      QString s = "apt-file search  ";
+      s += name;
 
-    QStringList filelist = kpty->run(s);
+      QStringList filelist = kpty->run(s);
 
-    for ( QStringList::Iterator it = filelist.begin(); it != filelist.end(); ++it ) {
-      int p =  (*it).find(": ");
-      if( p !=-1 )
-        (*it).replace(p, 2, "\t");
-    }
-
-    if (filelist.count() == 1) {
-      QStringList::Iterator it = filelist.begin();
-      if ((*it).find("not found") >= 0) {
-	filelist.remove(it);
+      for ( QStringList::Iterator it = filelist.begin(); it != filelist.end(); ++it ) {
+       int p =  (*it).find(": ");
+        if( p !=-1 )
+          (*it).replace(p, 2, "\t");
       }
-    }
 
-    return filelist;
+      if (filelist.count() == 1) {
+       QStringList::Iterator it = filelist.begin();
+        if ((*it).find("not found") >= 0) {
+	 filelist.remove(it);
+        }
+      }
+
+      return filelist;
+    } else {
+      KpMsg("Error",i18n("The %1 program needs to be installed").arg("apt-file"), TRUE);
+      QStringList nill;
+      return nill;
+    }
   } else {
     return DEB::FindFile(name);
   }
@@ -384,7 +405,7 @@ QStringList DEBAPT::getFileList(packageInfo *p)
 }
 
 //////////////////////////////////////////////////////////////////////////////
-QString DEBAPT::doUninstall(int uninstallFlags, QString packs, bool &test)
+QString DEBAPT::doUninstall(int uninstallFlags, const QString &packs, bool &test)
 {
   QString s = env + "apt-get remove ";
   s += setOptions(uninstallFlags, paramsUninst);
@@ -426,7 +447,7 @@ QString DEBAPT::install(int installFlags, QPtrList<packageInfo> *p,
   }
 }
 
-QString DEBAPT::doInstall(int installFlags, QString packs, bool &test)
+QString DEBAPT::doInstall(int installFlags, const QString &packs, bool &test)
 {
   QString s = env + "apt-get install ";
   s += setOptions(installFlags, paramsInst);
@@ -443,8 +464,16 @@ QString DEBAPT::doInstall(int installFlags, QString packs, bool &test)
 
 //////////////////////////////////////////////////////////////////////////////
 
-
 QStringList DEBAPT::readApt()
+{
+  if (hostName.isEmpty()) {
+    return readAptF();
+  } else {
+    return readAptS();
+  }
+}
+
+QStringList DEBAPT::readAptS()
 {
   QString cmd = "cat -E "  APT_SOURCE;
 
@@ -461,23 +490,45 @@ QStringList DEBAPT::readApt()
   }
 }
 
-void DEBAPT::writeApt(QStringList list) {
-  kdDebug() << "writeApt\n";
-  QString cmd = "sh -c 'echo -e ";
-  for ( QStringList::Iterator it = list.begin(); it != list.end(); ++it ) {
-    cmd += *it;
-    cmd += "\\";
-    cmd += "\\";
-    cmd += "n";
+QStringList DEBAPT::readAptF()
+{
+  QStringList lines;
+  QFile file( "/etc/apt/sources.list" );
+  if ( file.open( IO_ReadOnly ) ) {
+    QTextStream stream( &file );
+    QString line;
+    while ( !stream.atEnd() ) {
+      line = stream.readLine(); // line of text excluding '\n'
+      line = line.stripWhiteSpace();
+      lines += line;
+    }
+    file.close();
+    return lines;
+  } else {
+    return 0;
   }
-  cmd += "> /etc/apt/sources.list.n; if [ $? = 0 ]; then ";
-  cmd += "mv /etc/apt/sources.list /etc/apt/sources.list.b; mv /etc/apt/sources.list.n /etc/apt/sources.list; fi'";
+}
+
+void DEBAPT::writeApt(const QStringList &list) {
+  kdDebug() << "writeApt\n";
+  QString cmd = "sh -c \"echo -e '";
+  for ( QStringList::ConstIterator it = list.begin(); it != list.end(); ++it ) {
+    QString s = *it;
+    s.replace("\""," ");
+    s.replace("'"," ");
+    s.replace("!"," ");
+    s.replace("`"," ");
+    cmd += s;
+    cmd += "\n";
+  }
+  cmd += "' > /etc/apt/sources.list.n; if [ $? = 0 ]; then ";
+  cmd += "mv /etc/apt/sources.list /etc/apt/sources.list.b; mv /etc/apt/sources.list.n /etc/apt/sources.list; fi\" ";
   
 
  QStringList rlist =  kpty->run(cmd,TRUE,TRUE);
- for ( QStringList::Iterator it = rlist.begin(); it != rlist.end(); ++it ) {
-   kdDebug() << "SL=" << *it << "\n";
- }
+  //for ( QStringList::Iterator it = rlist.begin(); it != rlist.end(); ++it ) {
+  // kdDebug() << "SL=" << *it << "\n";
+  //}
 }
   
 
