@@ -113,7 +113,7 @@ void DEB::listUnIPackages(QPtrList<packageInfo> *pki, LcacheObj *pCache)
     } else {
       s = getDir(cp);
       if (!s.isEmpty()) {
-	listDir(pki,s,cp->location);
+	listDir(pki,s,cp->location,cp->subdirs);
       }
     }
   }
