@@ -20,8 +20,8 @@
 **
 ** You should have received a copy of the GNU General Public License
 ** along with this program in a file called COPYING; if not, write to
-** the Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
-** MA 02111-1307, USA.
+** the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+** MA 02110-1301, USA.
 */
 
 /*
@@ -257,7 +257,7 @@ void KPKG::writeSettings(){
 
   recent->saveEntries( config );
 
-  kpackage->management->treeList->writeTreePos();
+  kpackage->management->treeList->writeTreeConfig();
   kpackage->management->treeList->writeTreeType();
 
   config->sync();
@@ -488,17 +488,27 @@ pkgInterface *KPACKAGE::pkType(const QString &fname)
 }
 
 /////////////////////////////////////////////////////////////////////////
+int KPACKAGE::typeIndex(pkgInterface *type) {
+  int i;
+  for (i = 0; i < kpinterfaceN; i++) {
+    if (type ==  kpinterface[i]) {
+      return i;
+    }
+  }
+  return -1;
+}
 
-void KPACKAGE::openNetFiles (QStringList urls, bool install )
+void KPACKAGE::openNetFiles (const QStringList &urls, bool install )
 {
   QStringList files;
   int i;
+  int index;
   QPtrList<packageInfo> **lst = new QPtrList<packageInfo>*[kpinterfaceN];
   packageInfo *pk = 0;
 
   kdDebug() << "openNetFiles\n";
 
-  for (QStringList::Iterator it = urls.begin(); it != urls.end(); ++it) {
+  for (QStringList::ConstIterator it = urls.begin(); it != urls.end(); ++it) {
     files.append(fetchNetFile(*it));
     kpkg->add_recent_file(*it);
   }
@@ -506,18 +516,20 @@ void KPACKAGE::openNetFiles (QStringList urls, bool install )
   for (i = 0; i < kpinterfaceN; i++) {
     if (kpinterface[i]) {
       lst[i] = new QPtrList<packageInfo>;
-      for (QStringList::Iterator t = files.begin(); t != files.end(); ++t) {
-	pkgInterface *type = pkType(*t);
-	if (type ==  kpinterface[i]) {
-	  pk = type->getPackageInfo('u', *t, 0);
-	  if (pk) {
-	    pk->pkgFileIns(*t);
-	    lst[i]->insert(0,pk);
-	  }
-	}
-      }
     }
   }
+  
+  for (QStringList::Iterator t = files.begin(); t != files.end(); ++t) {
+    pkgInterface *type = pkType(*t);
+    index = typeIndex(type);
+    if (index >= 0) {
+      pk = type->getPackageInfo('u', *t, 0);
+      if (pk) {
+	pk->pkgFileIns(*t);
+	lst[index]->insert(0,pk);
+        }
+      }
+    }
 
   if (install)
     for (i = 0; i < kpinterfaceN; i++) {
@@ -544,9 +556,7 @@ void KPACKAGE::openNetFiles (QStringList urls, bool install )
   // Dealloc memory
   for (i = 0; i < kpinterfaceN; i++) {
     if (kpinterface[i]) {
-      if ( lst[i]->count() > 0) {
 	delete lst[i];
-      }
     }
   }
   delete [] lst;
