@@ -20,8 +20,8 @@
 **
 ** You should have received a copy of the GNU General Public License
 ** along with this program in a file called COPYING; if not, write to
-** the Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
-** MA 02111-1307, USA.
+** the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+** MA 02110-1301, USA.
 */
 
 /*
@@ -333,7 +333,7 @@ void managementWidget::collectData(bool refresh)
   dirUninstPackages->clear();
   // List installed packages
   for (i = 0; i < kpinterfaceN; i++)  {
-    if (kpinterface[i] && opts->handlePackage[i]) {
+    if (kpinterface[i] && kpinterface[i]->hasProgram && opts->handlePackage[i]) {
       if (hostName.isEmpty() || (kpinterface[i]->hasRemote)) {
 	kpinterface[i]->listPackages(allPackages);
       }
@@ -409,7 +409,9 @@ void managementWidget::installSingleClicked()
     pkgInterface *interface = package->interface;
     if (interface->noFetch || !filename.isEmpty()) {
       plist.append(package);
-      interface->installation->setup(&plist, interface->head);
+      if (!interface->installation->setup(&plist, interface->head)) {
+        return;
+      }
       result = interface->installation->exec();
 
       if (interface->installation->result() == QDialog::Accepted ||
@@ -478,12 +480,13 @@ void managementWidget::installMultClicked()
   for (i = 0; i < kpinterfaceN; i++) {
     if (kpinterface[i]) {
       if (lst[i]->count() > 0) {
-	kpinterface[i]->installation->setup(lst[i],kpinterface[i]->head);
-	if (kpinterface[i]->installation->exec() ||
+        if (kpinterface[i]->installation->setup(lst[i],kpinterface[i]->head)) {
+	 if (kpinterface[i]->installation->exec() ||
 	    kpinterface[i]->installation->modified) {
-	  for (inf = lst[i]->first(); inf != 0; inf = lst[i]->next()) {
-	    updatePackage(inf,TRUE);
-	  }
+	   for (inf = lst[i]->first(); inf != 0; inf = lst[i]->next()) {
+	     updatePackage(inf,TRUE);
+	   }
+          }
 	}
 	delete lst[i];
       }
@@ -507,7 +510,9 @@ void managementWidget::uninstallSingleClicked()
   if (package) {			// check that there is a package to uninstall
     pkgInterface *interface = package->interface;
     plist.append(package);
-    interface->uninstallation->setup(&plist, interface->head);
+    if (!interface->uninstallation->setup(&plist, interface->head)) {
+      return;
+    }
     result = interface->uninstallation->exec();
 
     if(result == QDialog::Accepted ||
@@ -560,14 +565,15 @@ void managementWidget::uninstallMultClicked()
   for (i = 0; i < kpinterfaceN; i++) {
     if (kpinterface[i]) {
       if (lst[i]->count() > 0) {
-	kpinterface[i]->uninstallation->setup(lst[i],kpinterface[i]->head);
-	if (kpinterface[i]->uninstallation->exec()||
+        if (kpinterface[i]->uninstallation->setup(lst[i],kpinterface[i]->head)) {
+	 if (kpinterface[i]->uninstallation->exec()||
 	    kpinterface[i]->installation->modified ) {
-	  for (inf = lst[i]->first(); inf != 0; inf = lst[i]->next()) {
-	    updatePackage(inf,FALSE);
-	  }
-	  delete lst[i];
-	}
+	   for (inf = lst[i]->first(); inf != 0; inf = lst[i]->next()) {
+	     updatePackage(inf,FALSE);
+	   }
+         }
+       }
+      delete lst[i];
       }
     }
   }
