@@ -1,6 +1,4 @@
 /***************************************************************************
-                          ServiceDlg.cpp  -  description
-                             -------------------
     begin                : Sun Oct 3 1999
     copyright            : (C) 1999 by Peter Putzer
     email                : putzer@kde.org
